searchData={"content_type":"text/markdown","items":[{"doc":"The package \"AutoDocPackage\" is used by the \"Auto Doc\" microservice\nfor generating API documentation based on OpenApiSpex format for Elixir projects.\n\nThis package handles the transmission of data\nbetween the `AutoDoc` microservice and your Elixir project.\nIt also generates the API Documentation directories and files filled with data,\nnested inside the respected `/documentation` directory.","ref":"AutoDocPackage.html","title":"AutoDocPackage","type":"module"},{"doc":"The package requires `:jason` and `:httpoison` to run while your project requires `:open_api_spex` as a documentation tool.\n\n- Dependencies:\n  - [`:jason`](https://hexdocs.pm/jason/Jason.html)\n  - [`:httpoison`](https://hexdocs.pm/httpoison/HTTPoison.html)\n  - [`:open_api_spex`](https://hexdocs.pm/open_api_spex/3.4.0/readme.html)","ref":"AutoDocPackage.html#module-prerequisites","title":"Prerequisites - AutoDocPackage","type":"module"},{"doc":"Add `auto_doc_package` to your list of dependencies in `mix.exs`:\n\n  ```elixir\n  def deps do\n    [\n      {:auto_doc_package, \"~> 0.1.1\"}\n    ]\n  end\n  ```","ref":"AutoDocPackage.html#module-installation","title":"Installation - AutoDocPackage","type":"module"},{"doc":"- A complete guide on registration and usage can be found in our [Github README](https://github.com/zen-dev-lab/auto_doc_package?tab=readme-ov-file#auto-doc-effortless-openapispex-documentation).\n- The package is licensed under [CC-BY-NC-ND-4.0](https://creativecommons.org/licenses/by-nc-nd/4.0/).\n- The product \"Auto Doc\" is hosted at [auto-doc.fly.dev](https://auto-doc.fly.dev).\n- The microservice itself works on a subscription basis.\n- The monthly subscription fee is 10€.\n- The product is currently in its initial phase and is being actively developed.","ref":"AutoDocPackage.html#module-extra-info","title":"Extra Info - AutoDocPackage","type":"module"},{"doc":"- `AutoDocPackage.Requests` - Used for generating the `example_data.json` file and the API Docs files based on the data provided by the `example_data.json` file.\n- `AutoDocPackage.Utils` - Contains utility functions used by the `AutoDocPackage` package.","ref":"AutoDocPackage.html#module-modules","title":"Modules - AutoDocPackage","type":"module"},{"doc":"The `AutoDocPackage.Requests` module is used for generating the `example_data.json` file\nand the API Docs files based on the data provided by the `example_data.json` file.\n\nThe module is used for the communication between the `AutoDoc` microservice and your Elixir project.\n\nMore information about the `AutoDoc` microservice can be found at:\n- [Auto Doc](https://auto-doc.fly.dev)\n- [Github README](https://github.com/zen-dev-lab/auto_doc_package?tab=readme-ov-file#auto-doc-effortless-openapispex-documentation).","ref":"AutoDocPackage.Requests.html","title":"AutoDocPackage.Requests","type":"module"},{"doc":"Generate the API Docs files based on the data provided by the `example_data.json` file.\nUsed for generating the API Docs files for the Params, Response, and Operations. (+ Errors)","ref":"AutoDocPackage.Requests.html#gen_api_spex/1","title":"AutoDocPackage.Requests.gen_api_spex/1","type":"function"},{"doc":"- `type` - The type of the API Docs file to be generated. Must be one of [:params, :response, :operations, \"params\", \"response\", \"operations\"].","ref":"AutoDocPackage.Requests.html#gen_api_spex/1-parameters","title":"Parameters - AutoDocPackage.Requests.gen_api_spex/1","type":"function"},{"doc":"- `{:ok, \"File formatted successfully.\"}` - If the file is successfully generated (since it's formatted in the end)\n  - `{:error, reason}` - If the file fails to be generated (`reason` here could be format failure or http response body/reason)","ref":"AutoDocPackage.Requests.html#gen_api_spex/1-returns","title":"Returns - AutoDocPackage.Requests.gen_api_spex/1","type":"function"},{"doc":"```elixir\n  iex> AutoDocPackage.Requests.gen_api_spex(:params)\n  {:ok, \"File formatted successfully.\"}\n  ```","ref":"AutoDocPackage.Requests.html#gen_api_spex/1-example","title":"Example - AutoDocPackage.Requests.gen_api_spex/1","type":"function"},{"doc":"Generate the `example_data.json` file containing the special keys(`__documentation_path__`, `__controller_path__`)\nand the keys corresponding to the API actions which do not yet have Documentation.","ref":"AutoDocPackage.Requests.html#gen_example_data_file/2","title":"AutoDocPackage.Requests.gen_example_data_file/2","type":"function"},{"doc":"- `example_data.json` is located under `/lib` directory of the project.\n  - the special keys MUST NOT be changed.\n  - the keys corresponding to the API actions are empty upon creation `{}` but\n    they should be filled by you(the user) with their respective HTTP Request/Response payload data.\n  - The data stored inside the `example_data.json` file is used for generating the API Docs files by the `gen_api_spex` function.","ref":"AutoDocPackage.Requests.html#gen_example_data_file/2-extra-info","title":"Extra Info: - AutoDocPackage.Requests.gen_example_data_file/2","type":"function"},{"doc":"- `documentation_path` - The relative path to the documentation folder.\n  - `controller_path` - The relative path to the controller file.","ref":"AutoDocPackage.Requests.html#gen_example_data_file/2-parameters","title":"Parameters - AutoDocPackage.Requests.gen_example_data_file/2","type":"function"},{"doc":"- `{:ok, \"File formatted successfully.\"}` - If the file is successfully generated (since it's formatted in the end)\n  - `{:error, reason}` - If the file fails to be generated (`reason` here could be format failure or http response body/reason)","ref":"AutoDocPackage.Requests.html#gen_example_data_file/2-returns","title":"Returns - AutoDocPackage.Requests.gen_example_data_file/2","type":"function"},{"doc":"```elixir\n  iex> documentation_path = \"auto_doc/lib/auto_doc_web/documentation\"\n  iex> controller_path = \"lib/auto_doc_web/controllers/page_controller.ex\"\n  iex> AutoDocPackage.Requests.gen_example_data_file(documentation_path, controller_path)\n  {:ok, \"File formatted successfully.\"}\n  ```","ref":"AutoDocPackage.Requests.html#gen_example_data_file/2-example","title":"Example - AutoDocPackage.Requests.gen_example_data_file/2","type":"function"},{"doc":"Utilities for the AutoDoc package.\nUsed for file manipulation, path conversion, and name conversion and more.\n\nNone of the functions here are meant to be used directly in your project.\nThey are meant to be used solely by the AutoDoc package to handle custom logic.","ref":"AutoDocPackage.Utils.html","title":"AutoDocPackage.Utils","type":"module"},{"doc":"Create nested directories.\nIf a directory already exists, it will not raise an error and will continue to the next one in line.\nIf the directory does not exist, it will create it and continue to the next one in line.\n\nImportant: The path should contain ONLY directories, not a file at the end or `../` in the beginning.","ref":"AutoDocPackage.Utils.html#create_nested_directories/1","title":"AutoDocPackage.Utils.create_nested_directories/1","type":"function"},{"doc":"Generates the file path for the documentation file.","ref":"AutoDocPackage.Utils.html#doc_file_path/3","title":"AutoDocPackage.Utils.doc_file_path/3","type":"function"},{"doc":"```elixir\n  iex> doc_file_path(\"auto_doc/lib/auto_doc/documentation\", \"lib/auto_doc_web/controllers/page_controller.ex\", \"params.ex\")\n  \"auto_doc/lib/auto_doc_web/documentation/page/params.ex\"\n  ```","ref":"AutoDocPackage.Utils.html#doc_file_path/3-examples","title":"Examples - AutoDocPackage.Utils.doc_file_path/3","type":"function"},{"doc":"Guess the possible documentation's inner-most directory \nfor the `params.ex`, `responses.ex`, `operations.ex` file paths.","ref":"AutoDocPackage.Utils.html#doc_path/2","title":"AutoDocPackage.Utils.doc_path/2","type":"function"},{"doc":"```elixir\n  iex> doc_path(\"auto_doc/lib/auto_doc/documentation\", \"lib/auto_doc_web/controllers/page_controller.ex\")\n  \"auto_doc/lib/auto_doc_web/documentation/page\"\n  ```","ref":"AutoDocPackage.Utils.html#doc_path/2-examples","title":"Examples - AutoDocPackage.Utils.doc_path/2","type":"function"},{"doc":"Checks if a file exists.","ref":"AutoDocPackage.Utils.html#file_exists?/1","title":"AutoDocPackage.Utils.file_exists?/1","type":"function"},{"doc":"```elixir\n  iex> file_exists?(\"lib/auto_doc/utils.ex\")\n  true\n\n  iex> file_exists?(\"auto_doc/lib/auto_doc/utils.ex\")\n  true\n\n  iex> file_exists?(\"lib/auto_doc/not_existing.ex\")\n  false\n  ```","ref":"AutoDocPackage.Utils.html#file_exists?/1-examples","title":"Examples - AutoDocPackage.Utils.file_exists?/1","type":"function"},{"doc":"","ref":"AutoDocPackage.Utils.html#find_schema_path/2","title":"AutoDocPackage.Utils.find_schema_path/2","type":"function"},{"doc":"","ref":"AutoDocPackage.Utils.html#is_camel_case?/1","title":"AutoDocPackage.Utils.is_camel_case?/1","type":"function"},{"doc":"Checks if a module name is a controller module.","ref":"AutoDocPackage.Utils.html#is_controller_module?/1","title":"AutoDocPackage.Utils.is_controller_module?/1","type":"function"},{"doc":"```elixir\n  iex> is_controller_module?(\"AutoDoc.PageController\")\n  true\n\n  iex> is_controller_module?(\"AutoDoc.PageView\")\n  false\n  ```","ref":"AutoDocPackage.Utils.html#is_controller_module?/1-examples","title":"Examples - AutoDocPackage.Utils.is_controller_module?/1","type":"function"},{"doc":"Checks if a module name is a controller test module.","ref":"AutoDocPackage.Utils.html#is_controller_test_module?/1","title":"AutoDocPackage.Utils.is_controller_test_module?/1","type":"function"},{"doc":"```elixir\n  iex> is_controller_test_module?(\"AutoDocWeb.PageControllerTest\")\n  true\n\n  iex> is_controller_test_module?(\"AutoDocWeb.PageController\")\n  false\n  ```","ref":"AutoDocPackage.Utils.html#is_controller_test_module?/1-examples","title":"Examples - AutoDocPackage.Utils.is_controller_test_module?/1","type":"function"},{"doc":"","ref":"AutoDocPackage.Utils.html#is_pascal_case?/1","title":"AutoDocPackage.Utils.is_pascal_case?/1","type":"function"},{"doc":"","ref":"AutoDocPackage.Utils.html#is_snake_case?/1","title":"AutoDocPackage.Utils.is_snake_case?/1","type":"function"},{"doc":"Checks if a module name is a test module.","ref":"AutoDocPackage.Utils.html#is_test_module?/1","title":"AutoDocPackage.Utils.is_test_module?/1","type":"function"},{"doc":"```elixir\n  iex> is_test_module?(\"AutoDoc.UtilsTest\")\n  true\n\n  iex> is_test_module?(\"AutoDoc.Utils\")\n  false\n  ```","ref":"AutoDocPackage.Utils.html#is_test_module?/1-examples","title":"Examples - AutoDocPackage.Utils.is_test_module?/1","type":"function"},{"doc":"Checks if a module name is a view module.","ref":"AutoDocPackage.Utils.html#is_view_module?/1","title":"AutoDocPackage.Utils.is_view_module?/1","type":"function"},{"doc":"```elixir\n  iex> is_view_module?(\"AutoDoc.PageView\")\n  true\n\n  iex> is_view_module?(\"AutoDoc.PageController\")\n  false\n  ```","ref":"AutoDocPackage.Utils.html#is_view_module?/1-examples","title":"Examples - AutoDocPackage.Utils.is_view_module?/1","type":"function"},{"doc":"Checks if a module name is a view test module.","ref":"AutoDocPackage.Utils.html#is_view_test_module?/1","title":"AutoDocPackage.Utils.is_view_test_module?/1","type":"function"},{"doc":"```elixir\n  iex> is_view_test_module?(\"AutoDocWeb.PageViewTest\")\n  true\n\n  iex> is_view_test_module?(\"AutoDocWeb.PageView\")\n  false\n  ```","ref":"AutoDocPackage.Utils.html#is_view_test_module?/1-examples","title":"Examples - AutoDocPackage.Utils.is_view_test_module?/1","type":"function"},{"doc":"Converts a module name to a path.","ref":"AutoDocPackage.Utils.html#module_name_to_path/2","title":"AutoDocPackage.Utils.module_name_to_path/2","type":"function"},{"doc":"```elixir\n  iex> module_name_to_path(\"AutoDoc.Utils\")\n  \"auto_doc/lib/auto_doc/utils.ex\"\n\n  iex> module_name_to_path(\"AutoDoc.UtilsTest\")\n  \"auto_doc/test/auto_doc/utils_test.exs\"\n  ```","ref":"AutoDocPackage.Utils.html#module_name_to_path/2-examples","title":"Examples - AutoDocPackage.Utils.module_name_to_path/2","type":"function"},{"doc":"Guess the possible documentation's `operations.ex` file path.","ref":"AutoDocPackage.Utils.html#operations_path/2","title":"AutoDocPackage.Utils.operations_path/2","type":"function"},{"doc":"```elixir\n  iex> operations_path(\"auto_doc/lib/auto_doc/documentation\", \"lib/auto_doc_web/controllers/page_controller.ex\")\n  \"auto_doc/lib/auto_doc_web/documentation/page/operations.ex\"\n\n  iex> operations_path(\"auto_doc/lib/auto_doc/private/v2/documentation\", \"lib/auto_doc_web/private/v2/controllers/page_controller.ex\")\n  \"auto_doc/lib/auto_doc_web/private/v2/documentation/page/operations.ex\"\n  ```","ref":"AutoDocPackage.Utils.html#operations_path/2-examples","title":"Examples - AutoDocPackage.Utils.operations_path/2","type":"function"},{"doc":"Parses the file path from relative to usable type.","ref":"AutoDocPackage.Utils.html#parse_file_path/1","title":"AutoDocPackage.Utils.parse_file_path/1","type":"function"},{"doc":"```elixir\n  iex> parse_file_path(\"lib/auto_doc/utils.ex\")\n  \"auto_doc/lib/auto_doc/utils.ex\"\n\n  iex> parse_file_path(\"auto_doc/lib/auto_doc/utils.ex\")\n  \"auto_doc/lib/auto_doc/utils.ex\"\n  ```","ref":"AutoDocPackage.Utils.html#parse_file_path/1-examples","title":"Examples - AutoDocPackage.Utils.parse_file_path/1","type":"function"},{"doc":"Converts a path to a module name.","ref":"AutoDocPackage.Utils.html#path_to_module_name/1","title":"AutoDocPackage.Utils.path_to_module_name/1","type":"function"},{"doc":"```elixir\n  iex> path_to_module_name(\"auto_doc/lib/auto_doc/utils.ex\")\n  \"AutoDoc.Utils\"\n\n  iex> path_to_module_name(\"auto_doc/test/auto_doc/utils_test.exs\")\n  \"AutoDoc.UtilsTest\"\n  ```","ref":"AutoDocPackage.Utils.html#path_to_module_name/1-examples","title":"Examples - AutoDocPackage.Utils.path_to_module_name/1","type":"function"},{"doc":"Returns the name of the project container.","ref":"AutoDocPackage.Utils.html#project_container_name/0","title":"AutoDocPackage.Utils.project_container_name/0","type":"function"},{"doc":"```elixir\n  iex> project_container_name()\n  \"auto_doc\"\n  ```","ref":"AutoDocPackage.Utils.html#project_container_name/0-examples","title":"Examples - AutoDocPackage.Utils.project_container_name/0","type":"function"},{"doc":"Read file and returns the content.","ref":"AutoDocPackage.Utils.html#read_file/1","title":"AutoDocPackage.Utils.read_file/1","type":"function"},{"doc":"Runs `mix format` on given file.","ref":"AutoDocPackage.Utils.html#run_mix_format/1","title":"AutoDocPackage.Utils.run_mix_format/1","type":"function"},{"doc":"```elixir\n  iex> run_mix_format(\"lib/auto_doc/utils.ex\")\n  {:ok, \"File formatted successfully.\"}\n\n  iex> run_mix_format(\"lib/auto_doc/utils.ex\")\n  {:error, \"File formatting failed. File: \"lib/auto_doc/utils.ex\"\"}\n  ```","ref":"AutoDocPackage.Utils.html#run_mix_format/1-examples","title":"Examples - AutoDocPackage.Utils.run_mix_format/1","type":"function"},{"doc":"Converts a string to camelCase.","ref":"AutoDocPackage.Utils.html#to_camel_case/1","title":"AutoDocPackage.Utils.to_camel_case/1","type":"function"},{"doc":"```elixir\n  iex> to_camel_case(\"helloWorld\")\n  \"helloWorld\"\n\n  iex> to_camel_case(\"hello_world\")\n  \"helloWorld\"\n\n  iex> to_camel_case(\"HelloWorld\")\n  \"helloWorld\"\n\n  iex> to_camel_case(\"Invalid_Type\")\n  ** (ArgumentError)\n  ** ...\n  ```","ref":"AutoDocPackage.Utils.html#to_camel_case/1-examples","title":"Examples - AutoDocPackage.Utils.to_camel_case/1","type":"function"},{"doc":"Converts a string to PascalCase.","ref":"AutoDocPackage.Utils.html#to_pascal_case/1","title":"AutoDocPackage.Utils.to_pascal_case/1","type":"function"},{"doc":"```elixir\n  iex> to_pascal_case(\"helloWorld\")\n  \"HelloWorld\"\n\n  iex> to_pascal_case(\"hello_world\")\n  \"HelloWorld\"\n\n  iex> to_pascal_case(\"HelloWorld\")\n  \"HelloWorld\"\n\n  iex> to_pascal_case(\"Invalid_Type\")\n  ** (ArgumentError)\n  ** ...\n  ```","ref":"AutoDocPackage.Utils.html#to_pascal_case/1-examples","title":"Examples - AutoDocPackage.Utils.to_pascal_case/1","type":"function"},{"doc":"Converts a string to snake_case.","ref":"AutoDocPackage.Utils.html#to_snake_case/1","title":"AutoDocPackage.Utils.to_snake_case/1","type":"function"},{"doc":"```elixir\n  iex> to_snake_case(\"helloWorld\")\n  \"hello_world\"\n\n  iex> to_snake_case(\"hello_world\")\n  \"hello_world\"\n\n  iex> to_snake_case(\"HelloWorld\")\n  \"hello_world\"\n\n  iex> to_snake_case(\"Invalid_Type\")\n  ** (ArgumentError)\n  ** ...\n  ```","ref":"AutoDocPackage.Utils.html#to_snake_case/1-examples","title":"Examples - AutoDocPackage.Utils.to_snake_case/1","type":"function"},{"doc":"Write to file.","ref":"AutoDocPackage.Utils.html#write_file/3","title":"AutoDocPackage.Utils.write_file/3","type":"function"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}